<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name>Wizard</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Kreator konfiguracji Kadu</translation>
    </message>
    <message>
        <source>I have a number</source>
        <translation>Mam już numer</translation>
    </message>
    <message>
        <source>Gadu-gadu number</source>
        <translation>Numer GG</translation>
    </message>
    <message>
        <source>Gadu-gadu password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Import contacts</source>
        <translation>Zaimportuj kontakty</translation>
    </message>
    <message>
        <source>Your e-mail address</source>
        <translation>Adres e-mail</translation>
    </message>
    <message>
        <source>Choose your browser</source>
        <translation>Wybierz przeglądarkę</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Błędnie wprowadzone dane.

Hasło powinno w obu polach być takie same!</translation>
    </message>
    <message>
        <source>An error has occured while registration. Please try again later.</source>
        <translation>Wystąpił błąd podczas rejestracji. Spróbuj ponownie później.</translation>
    </message>
    <message>
        <source>User list wasn&apos;t imported because of some error</source>
        <translation>Lista kontaktów nie została zaimportowana z powodu błędu</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Rejestruj</translation>
    </message>
    <message>
        <source>Registration was successful.
You UIN is: </source>
        <translation>Rejestracja zakończona sukcesem.
Twój nr GG: </translation>
    </message>
    <message>
        <source>
Account configuration was saved.
Press Ok to continue</source>
        <translation>
Konfiguracja konta została zapisana.
Naciśnij Ok by kontynuować</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Proszę wypełnić wszystkie pola</translation>
    </message>
    <message>
        <source>Email address you have entered is not valid</source>
        <translation>Podany adres e-mail jest nie prawidłowy</translation>
    </message>
    <message>
        <source>I don&apos;t have a number</source>
        <translation>Nie posiadam numeru</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>Nowe hasło</translation>
    </message>
    <message>
        <source>Retype password</source>
        <translation>Powtórz hasło</translation>
    </message>
    <message>
        <source>Specify path</source>
        <translation>Specyficzna ścieżka</translation>
    </message>
    <message>
        <source>Konqueror</source>
        <translation>Konqueror</translation>
    </message>
    <message>
        <source>Opera</source>
        <translation>Opera</translation>
    </message>
    <message>
        <source>Mozilla</source>
        <translation>Mozilla</translation>
    </message>
    <message>
        <source>Mozilla Firefox</source>
        <translation>Mozilla Firefox</translation>
    </message>
    <message>
        <source>Dillo</source>
        <translation>Dillo</translation>
    </message>
    <message>
        <source>Galeon</source>
        <translation>Galeon</translation>
    </message>
    <message>
        <source>Safari</source>
        <translation>Safari</translation>
    </message>
    <message>
        <source>Custom browser</source>
        <translation>Własny wybór</translation>
    </message>
    <message>
        <source>Choose your e-mail client</source>
        <translation>Wybierz swojego klienta e-mail</translation>
    </message>
    <message>
        <source>KMail</source>
        <translation>KMail</translation>
    </message>
    <message>
        <source>Thunderbird</source>
        <translation>Thunderbird</translation>
    </message>
    <message>
        <source>SeaMonkey</source>
        <translation>SeaMonkey</translation>
    </message>
    <message>
        <source>Evolution</source>
        <translation>Evolution</translation>
    </message>
    <message>
        <source>Custom e-mail client</source>
        <translation>Własny wybór</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Aplikacje</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please setup Kadu for working with your favourite WWW browser and email program.&lt;/p&gt;&lt;p&gt;Kadu will use these for opening various links from messages and user&apos;s descriptions&lt;/p&gt;</source>
        <translation>&lt;p&gt;Proszę ustawić programy do współpracy Kadu ze stronami WWW i pocztą e-mail.&lt;/p&gt;&lt;p&gt;Kadu będzie ich używac do otwierania linków z wiadomości i opisów użytkowników&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Test sound</source>
        <translation>Test dźwięku</translation>
    </message>
    <message>
        <source>&lt;p&gt;Please select your sound driver for sound notifications. If you don&apos;t want sound notifications, use None driver.&lt;/p&gt;&lt;p&gt;If you don&apos;t know which driver to use, just check every ony with Test sound button.Don&apos;t forget to unmute your system before!&lt;/p&gt;</source>
        <translation>&lt;p&gt;Proszę wybrać odpowiedni system dźwięku dla powiadomień sygnałami dźwiękowymi. Jeżeli nie chcesz być powiadamiany dźwiękiem wybierz &quot;None&quot;.&lt;/p&gt;Jeśli nie wiesz jaki system dźwięku jest przez ciebie używany, sprawdź po kolei wszystkie testując przyciskiem &quot;Test dźwięku&quot;. Nie zapomnij wcześniej ustawić mikser na odpowiednią siłę głosu!&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Welcome in Kadu&lt;/h3&gt;&lt;h4&gt;the Gadu-gadu network client for *nix and MacOS X.&lt;/h4&gt;&lt;p&gt;This is first time you launch Kadu. This wizard will help you to configure the basic settings of Kadu. If you are experienced Kadu user you may omit the wizard by clicking Cancel.&lt;/p&gt;&lt;p&gt;Please enter your account data. If you don&apos;t have one, you can create new here.&lt;/p&gt;&lt;p&gt;E-mail address is needed when you want to recover lost password to account&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Witamy w Kadu&lt;/h3&gt;&lt;h4&gt;kliencie sieci Gadu-Gadu dla systemów *nix i MacOS X.&lt;/h4&gt;&lt;p&gt;Uruchomiłeś Kadu po raz pierwszy.Ten kreator pomoże ci ustawić podstawową konfigurację programu. Jeśli jesteś doświadczonym użytkownikiem możesz go pominąć klikając na przycisk &quot;Anuluj&quot;.&lt;/p&gt;&lt;p&gt;Proszę wprowadzić swoje dane konta GG. Jeśli go nie posiadasz możesz je teraz utworzyć.&lt;/p&gt;&lt;p&gt;Adres e-mail jest potrzebny do przypomnienia zapomnianego hasła&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Gadu-gadu account</source>
        <translation>Konto Gadu-Gadu</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>System dźwiękowy</translation>
    </message>
    <message>
        <source>Opera (new tab)</source>
        <translation>Opera (nowa karta)</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Nie znaleziono</translation>
    </message>
</context>
<context>
    <name>WizardStarter</name>
    <message>
        <source>Configuration Wizard</source>
        <translation>Kreator konfiguracji</translation>
    </message>
    <message>
        <source>User list couldn&apos;t be imported</source>
        <translation>Lista kontaktów nie została zaimportowana</translation>
    </message>
</context>
</TS>
